#ifndef XmlError_h
#define XmlError_h

// $Id: XmlError.h,v 1.8 2012/12/20 15:53:17 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA 02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"

#include <QtCore/QString>
#include <QtCore/QTextStream>
#include <QtCore/QList>

//! Xml parsing error container
class XmlError: public Counter
{

    public:

    //! shortcut to list of errors
    typedef QList<XmlError> List;

    //! constructor
    XmlError( const File& file = File() ):
        Counter( "XmlError" ),
        file_ ( file ),
        error_( "" ),
        line_(0),
        column_(0)
    {}

    //!@name accessors
    //@{

    //! cast to boolean
    operator bool(void) const
    { return error_.length() != 0; }

    //! File
    const QString& file( void ) const
    { return file_; }

    //! error
    const QString& error( void ) const
    { return error_; }

    //! line
    const int& line( void ) const
    { return line_; }

    //! column
    const int& column( void ) const
    { return column_; }

    //@}

    //!@name modifiers
    //@{

    //! clear
    void clear( void )
    {
        file_.clear();
        error_.clear();
        line_ = -1;
        column_ = -1;
    }

    //! set file
    void setFile( const File& file )
    { file_ = file; }

        //! error
    QString& error( void )
    { return error_; }

    //! line
    int& line( void )
    { return line_; }

    //! column
    int& column( void )
    { return column_; }

    //@}

    private:

    //! file
    File file_;

    //! error
    QString error_;

    //! line
    int line_;

    //! column
    int column_;

    //! dumper
    friend QTextStream& operator << ( QTextStream &out, const XmlError& error )
    {
        if( !error.file().isEmpty() ) out << error.file() << ": ";
        else out << "message: ";
        out << error.error() << " at line " << error.line() << ", column " << error.column();
        return out;
    }

    //! dumper
    friend QTextStream& operator << ( QTextStream &out, const List& errors )
    {
        foreach( const XmlError& error, errors )
        { out << error << endl; }
        return out;
    }

};

#endif
