// $Id: EditAttachmentDialog.cpp,v 1.14 2012/02/20 10:44:15 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/

/*!
\file EditAttachmentDialog.cpp
\brief open attachment popup dialog
\author Hugo Pereira
\version $Revision: 1.14 $
\date $Date: 2012/02/20 10:44:15 $
*/

#include <QLayout>
#include <QLabel>

#include "GridLayout.h"
#include "AnimatedLineEditor.h"
#include "Debug.h"
#include "EditAttachmentDialog.h"
#include "File.h"



//_____________________________________________________
EditAttachmentDialog::EditAttachmentDialog( QWidget* parent, const Attachment& attachment ):
CustomDialog( parent )
{

    Debug::Throw( "EditAttachmentDialog::EditAttachmentDialog.\n" );

    GridLayout* gridLayout = new GridLayout();
    gridLayout->setMargin(0);
    gridLayout->setSpacing(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignVCenter|Qt::AlignRight );
    mainLayout().addLayout( gridLayout );

    // file name
    gridLayout->addWidget( new QLabel( "File:", this ) );
    AnimatedLineEditor *file_line_edit( new AnimatedLineEditor( this ) );
    file_line_edit->setReadOnly( true );
    file_line_edit->setToolTip( "Attachment file/URL. (read-only)" );
    gridLayout->addWidget( file_line_edit );

    AttachmentType type( attachment.type() );
    File fullname( ( type == AttachmentType::URL ) ? attachment.file():attachment.file().expand() );
    file_line_edit->setText( fullname );

    // type
    gridLayout->addWidget( new QLabel( "Type:", this ) );
    gridLayout->addWidget( fileTypeComboBox_ = new QComboBox( this ) );
    for(
        AttachmentType::Map::const_iterator iter = AttachmentType::types().begin();
    iter != AttachmentType::types().end();
    iter ++ )
    {

        if( type == AttachmentType::URL && !( iter.value() == AttachmentType::URL ) ) continue;
        if( !( type == AttachmentType::URL ) && iter.value() == AttachmentType::URL ) continue;
        fileTypeComboBox_->addItem( iter.value().name() );

    }
    fileTypeComboBox_->setCurrentIndex( fileTypeComboBox_->findText( type.name() ) );
    fileTypeComboBox_->setToolTip( "Attachment type. Defines the default application used to display the attachment." );

    // creation
    gridLayout->addWidget( new QLabel( "Created: ", this ) );
    gridLayout->addWidget( new QLabel( attachment.creation().isValid() ? attachment.creation().toString():"-", this ) );

    // modification
    gridLayout->addWidget( new QLabel( "Modified: ", this ) );
    gridLayout->addWidget( new QLabel( attachment.modification().isValid() ? attachment.modification().toString():"-", this ) );

    gridLayout->setColumnStretch( 1, 1 );

    QVBoxLayout* boxLayout = new QVBoxLayout();
    boxLayout->setMargin(0);
    boxLayout->setSpacing(5);
    mainLayout().addLayout( boxLayout, 1 );

    boxLayout->addWidget( new QLabel( "Comments:", this ), 0 );
    boxLayout->addWidget( commentsEditor_ = new TextEditor( this ), 1 );
    commentsEditor_->setPlainText( attachment.comments() );
    commentsEditor_->setToolTip( "Attachment comments." );

}

//____________________________________________
AttachmentType EditAttachmentDialog::type( void ) const
{

    Debug::Throw( "EditAttachmentDialog::GetType.\n" );
    QString type_string( fileTypeComboBox_->currentText() );
    for(
        AttachmentType::Map::const_iterator iter = AttachmentType::types().begin();
    iter != AttachmentType::types().end();
    ++iter )
    { if( iter.value().name() == type_string ) return iter.value(); }
    return AttachmentType::UNKNOWN;

}


//____________________________________________________
QString EditAttachmentDialog::comments( void ) const
{
    Debug::Throw( "EditAttachmentDialog::comments.\n" );
    return commentsEditor_->toPlainText();
}
