#ifndef NewLogbookDialog_h
#define NewLogbookDialog_h

// $Id: NewLogbookDialog.h,v 1.14 2012/09/24 12:02:33 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/

#include "AnimatedLineEditor.h"
#include "BrowsedLineEditor.h"
#include "CustomDialog.h"
#include "TextEditor.h"
#include "File.h"
#include "Debug.h"

#include <QtCore/QString>

//! new attachment popup dialog
class NewLogbookDialog: public CustomDialog
{

    public:

    //! constructor
    NewLogbookDialog( QWidget* parent );

    //! destructor
    virtual ~NewLogbookDialog( void )
    { Debug::Throw( "NewLogbookDialog::~NewLogbookDialog\n" ); }

    //! title
    void setTitle( const QString& title )
    { title_->setText( title ); }

    //! title
    QString title( void ) const
    { return title_->text(); }

    //! author
    void setAuthor( const QString& author )
    { author_->setText( author ); }

    //! filename
    QString author( void ) const
    { return author_->text(); }

    //! filename
    void setFile( const File& file )
    { file_->setFile( file ); }

    //! filename
    File file( void ) const
    { return File( file_->editor().text() ).expand(); }

    //! attachment directory
    void setAttachmentDirectory( const File& file )
    { attachmentDirectory_->setFile( file ); }

    //! attachment directory
    File attachmentDirectory( void ) const
    { return File( attachmentDirectory_->editor().text() ).expand(); }

    //! comments
    void setComments( const QString& comments )
    {
        Debug::Throw( "NewLogbookDialog::setComments.\n" );
        comments_->setPlainText( comments );
    }

    //! comments
    QString comments( void ) const
    { return comments_->toPlainText(); }

    private:

    //! title line edit
    AnimatedLineEditor *title_;

    //! author line edit
    AnimatedLineEditor *author_;

    //! filename browsed line editor
    BrowsedLineEditor *file_;

    //! destination directory browsed line edti
    BrowsedLineEditor *attachmentDirectory_;

    //! comments
    TextEditor *comments_;

};

#endif
